#!/bin/bash

# Store the current working directory
CURRENT_DIR="$(pwd)"

# Symlink VSCode settings.json to your VSCode configuration folder
VS_CODE_SETTINGS_DIR="$HOME/.config/Code/User"
VS_CODE_SETTINGS_FILE="$CURRENT_DIR/configs/vscode/settings.json"
BACKUP_VS_CODE_SETTINGS_FILE="$CURRENT_DIR/configs/vscode/settings.json.backup"

# Remove symlink and restore backup if it exists
if [ -L "$VS_CODE_SETTINGS_FILE" ]; then
    rm "$VS_CODE_SETTINGS_FILE"
    echo "Removed symlink to VSCode settings.json"

    if [ -f "$BACKUP_VS_CODE_SETTINGS_FILE" ]; then
        mv "$BACKUP_VS_CODE_SETTINGS_FILE" "$VS_CODE_SETTINGS_FILE"
        echo "Restored original VSCode settings from $BACKUP_VS_CODE_SETTINGS_FILE"
    fi
fi

# Remove sourcing of .bashrc.k from ~/.bashrc
BASHRC_FILE="$HOME/.bashrc"
BASHRC_K_FILE="$CURRENT_DIR/configs/bash/.bashrc.k"
BACKUP_BASHRC_FILE="$CURRENT_DIR/configs/bash/.bashrc.backup"

if grep -q ".bashrc.k" "$BASHRC_FILE"; then
    # Remove the line that sources .bashrc.k
    sed -i '/\.bashrc\.k/d' "$BASHRC_FILE"
    echo "Removed sourcing of .bashrc.k from $BASHRC_FILE"

    # Restore the original .bashrc if it exists
    if [ -f "$BACKUP_BASHRC_FILE" ]; then
        cp "$BACKUP_BASHRC_FILE" "$BASHRC_FILE"
        echo "Restored original .bashrc from $BACKUP_BASHRC_FILE"
    fi
else
    echo "Warning: .bashrc does not source .bashrc.k. No action taken."
fi

# Go back to the original working directory
cd "$CURRENT_DIR"

echo "All settings disabled. Changes reverted if applicable."
