#!/bin/bash

# Store the current working directory
CURRENT_DIR="$(pwd)"

# === [ VSCode ] ===

# Symlink VSCode settings.json to your VSCode configuration folder
VS_CODE_SETTINGS_DIR="$HOME/.config/Code/User"
VS_CODE_SETTINGS_FILE="$CURRENT_DIR/configs/vscode/settings.json"
BACKUP_VS_CODE_SETTINGS_FILE="$CURRENT_DIR/configs/vscode/settings.json.backup"

# Backup existing VSCode settings if they exist
if [ -f "$VS_CODE_SETTINGS_FILE" ]; then
    mv "$VS_CODE_SETTINGS_FILE" "$BACKUP_VS_CODE_SETTINGS_FILE"
    echo "Backed up existing VSCode settings to $BACKUP_VS_CODE_SETTINGS_FILE"
fi

ln -s "$VS_CODE_SETTINGS_FILE" "$VS_CODE_SETTINGS_DIR/settings.json"
echo "Symlinked VSCode settings.json to $VS_CODE_SETTINGS_DIR"

# === [ BashRC ] ===

# Add sourcing of .bashrc.k to ~/.bashrc
BASHRC_FILE="$HOME/.bashrc"
BASHRC_K_FILE="$CURRENT_DIR/configs/bash/.bashrc.k"
BACKUP_BASHRC_FILE="$CURRENT_DIR/configs/bash/.bashrc.backup"

# Backup existing .bashrc if it exists
if [ -f "$BASHRC_FILE" ]; then
    cp "$BASHRC_FILE" "$BACKUP_BASHRC_FILE"
    echo "Backed up existing .bashrc to $BACKUP_BASHRC_FILE"
fi

# Check if .bashrc already sources .bashrc.k
if grep -q ".bashrc.k" "$BASHRC_FILE"; then
    echo "Warning: .bashrc already sources .bashrc.k"
else
    echo -e "\n# Source .bashrc.k\nsource \"$BASHRC_K_FILE\"" >> "$BASHRC_FILE"
    echo "Added sourcing of .bashrc.k to $BASHRC_FILE"
fi

# Go back to the original working directory
cd "$CURRENT_DIR"

echo "All settings enabled. Changes applied."
